Method

Enum Method 

pub enum Method {
Show 33 variants Delete, Get, Head, Post, Put, Connect, Options, Trace, Copy, Lock, MkCol, Move, Propfind, Proppatch, Search, Unlock, Bind, Rebind, Unbind, Acl, Report, MkActivity, Checkout, Merge, MSearch, Notify, Subscribe, Unsubscribe, Patch, Purge, MkCalendar, Link, Unlink,
}

Variants



Delete



Get



Head



Post



Put



Connect



Options



Trace



Copy



Lock



MkCol



Move



Propfind



Proppatch



Search



Unlock



Bind



Rebind



Unbind



Acl



Report



MkActivity



Checkout



Merge



MSearch



Notify



Subscribe



Unsubscribe



Patch



Purge



MkCalendar